@@ -6,9 +6,9 @@ Type annotations for backup service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_backup.literals import BackupJobState
+    from mypy_boto3_backup.literals import BackupJobStateType
 
-    data: BackupJobState = "ABORTED"
+    data: BackupJobStateType = "ABORTED"
     ```
 """
 import sys
@@ -20,20 +20,20 @@ else:
 
 
 __all__ = (
-    "BackupJobState",
-    "BackupVaultEvent",
-    "ConditionType",
-    "CopyJobState",
-    "RecoveryPointStatus",
-    "RestoreJobStatus",
-    "StorageClass",
+    "BackupJobStateType",
+    "BackupVaultEventType",
+    "ConditionTypeType",
+    "CopyJobStateType",
+    "RecoveryPointStatusType",
+    "RestoreJobStatusType",
+    "StorageClassType",
 )
 
 
-BackupJobState = Literal[
+BackupJobStateType = Literal[
     "ABORTED", "ABORTING", "COMPLETED", "CREATED", "EXPIRED", "FAILED", "PENDING", "RUNNING"
 ]
-BackupVaultEvent = Literal[
+BackupVaultEventType = Literal[
     "BACKUP_JOB_COMPLETED",
     "BACKUP_JOB_EXPIRED",
     "BACKUP_JOB_FAILED",
@@ -50,8 +50,8 @@ BackupVaultEvent = Literal[
     "RESTORE_JOB_STARTED",
     "RESTORE_JOB_SUCCESSFUL",
 ]
-ConditionType = Literal["STRINGEQUALS"]
-CopyJobState = Literal["COMPLETED", "CREATED", "FAILED", "RUNNING"]
-RecoveryPointStatus = Literal["COMPLETED", "DELETING", "EXPIRED", "PARTIAL"]
-RestoreJobStatus = Literal["ABORTED", "COMPLETED", "FAILED", "PENDING", "RUNNING"]
-StorageClass = Literal["COLD", "DELETED", "WARM"]
+ConditionTypeType = Literal["STRINGEQUALS"]
+CopyJobStateType = Literal["COMPLETED", "CREATED", "FAILED", "RUNNING"]
+RecoveryPointStatusType = Literal["COMPLETED", "DELETING", "EXPIRED", "PARTIAL"]
+RestoreJobStatusType = Literal["ABORTED", "COMPLETED", "FAILED", "PENDING", "RUNNING"]
+StorageClassType = Literal["COLD", "DELETED", "WARM"]
